==> jupyter_pieces-1.22.0.tar.gz: jupyter_pieces-1.22.0/src/ui/views/drive/driveApplets.ts <==
import { AppletCapabilities } from '../shared/types/AppletCapabilitiesEnum';
import { copilotParams } from '../copilot/CopilotParams';
import getTheme from '../shared/theme';
import { OSAppletEnum } from '@pieces.app/pieces-os-client';
import ConnectorSingleton from '../../../connection/connectorSingleton';
import { Applet } from '../shared/applet'

export default class SnippetsApplet extends Applet {
	constructor() {
		super('pieces-snippets', 'snippets-tab');
	}

	async getUrl() {
		const application = await copilotParams.getApplication();
		const baseUrl = await ConnectorSingleton.getInstance().osApi.osAppletLaunch(
			{
				inactiveOSServerApplet: {
					type: OSAppletEnum.SavedMaterials,
					parent: application,
				},
			}
		);

		const url = new URL(`http://localhost:${baseUrl.port}`);
		const theme = getTheme();

		url.searchParams.append('theme', JSON.stringify(theme));
		url.searchParams.append('application', JSON.stringify(application));
		url.searchParams.append(
			'capabilities',
			(
				// AppletCapabilities.insertAtCursor |
				AppletCapabilities.askCopilot |
				AppletCapabilities.displayNotification |
				AppletCapabilities.persistState |
				AppletCapabilities.launchPos |
				// AppletCapabilities.corsProxy |
				AppletCapabilities.setTheme |
				AppletCapabilities.addToContext |
				AppletCapabilities.copyToClipboard |
				AppletCapabilities.loaded |
				// AppletCapabilities.previewAsset |
				AppletCapabilities.openSettings |
				AppletCapabilities.focusCopilotConversation|
				AppletCapabilities.runInTerminal  // Getting type = null here which is super wired!
			).toString()
		);

		return url;
	}
}

export const snippetApplet = new SnippetsApplet();

==> jupyter_pieces-1.23.0.tar.gz: jupyter_pieces-1.23.0/src/ui/views/drive/driveApplets.ts <==
import { AppletCapabilities } from '../shared/types/AppletCapabilitiesEnum';
import { copilotParams } from '../copilot/CopilotParams';
import getTheme from '../shared/theme';
import { OSAppletEnum } from '@pieces.app/pieces-os-client';
import ConnectorSingleton from '../../../connection/connectorSingleton';
import { Applet } from '../shared/applet'

export default class SnippetsApplet extends Applet {
	constructor() {
		super('pieces-snippets', 'drive-applet-container');
	}

	async getUrl() {
		const application = await copilotParams.getApplication();
		const baseUrl = await ConnectorSingleton.getInstance().osApi.osAppletLaunch(
			{
				inactiveOSServerApplet: {
					type: OSAppletEnum.SavedMaterials,
					parent: application,
				},
			}
		);

		const url = new URL(`http://localhost:${baseUrl.port}`);
		const theme = getTheme();

		url.searchParams.append('theme', JSON.stringify(theme));
		url.searchParams.append('application', JSON.stringify(application));
		url.searchParams.append(
			'capabilities',
			(
				// AppletCapabilities.insertAtCursor |
				AppletCapabilities.askCopilot |
				AppletCapabilities.displayNotification |
				AppletCapabilities.persistState |
				AppletCapabilities.launchPos |
				// AppletCapabilities.corsProxy |
				AppletCapabilities.setTheme |
				AppletCapabilities.addToContext |
				AppletCapabilities.copyToClipboard |
				AppletCapabilities.loaded |
				// AppletCapabilities.previewAsset |
				AppletCapabilities.openSettings |
				AppletCapabilities.focusCopilotConversation|
				AppletCapabilities.runInTerminal  // Getting type = null here which is super wired!
			).toString()
		);

		return url;
	}
}

export const driveApplet = new SnippetsApplet();
